sql_dialects: List supported SQL dialects

View source: R/metadata.R

sql_dialectsR Documentation

List supported SQL dialects

Description

List supported SQL dialects

Usage

sql_dialects(full = FALSE)

Arguments

full

If FALSE (default), return a character vector of canonical dialect names. If TRUE, return a data frame with columns name, aliases (comma-separated accepted aliases) and description.

Details

Every function that takes a dialect, from or to argument accepts both the canonical names and the aliases (e.g. "postgresql" for "postgres", "mssql" or "sqlserver" for "tsql").

Value

A character vector, or a data frame when full = TRUE.

Examples

sql_dialects()
head(sql_dialects(full = TRUE))

polyglotSQL documentation built on Sept. 27, 2026, 5:06 p.m.