| sql_dialects | R Documentation |
List supported SQL dialects
sql_dialects(full = FALSE)
full |
If |
Every function that takes a dialect, from or to argument
accepts both the canonical names and the aliases (e.g. "postgresql"
for "postgres", "mssql" or "sqlserver" for "tsql").
A character vector, or a data frame when full = TRUE.
sql_dialects()
head(sql_dialects(full = TRUE))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.