| sql_format | R Documentation |
Parses and re-renders SQL as canonically indented statements. Complexity
guards protect against pathological inputs; exceeding a guard raises a
polyglot_guard_error.
sql_format(
sql,
dialect = "generic",
max_input_bytes = NULL,
max_tokens = NULL,
max_ast_nodes = NULL,
max_set_op_chain = NULL
)
sql |
A single character string with one or more SQL statements
(separated by |
dialect |
Dialect used for parsing and rendering. |
max_input_bytes, max_tokens, max_ast_nodes, max_set_op_chain |
Complexity
guard limits. |
A character vector with one formatted statement per input statement.
cat(sql_format("select a,b from t where x=1 and y=2"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.