| sql_optimize | R Documentation |
Applies the upstream optimizer rule set (predicate pushdown, join reordering, CTE and subquery elimination, expression simplification, etc.) and returns the rewritten SQL.
sql_optimize(sql, dialect = "generic", schema = NULL)
sql |
A single character string with one or more SQL statements
(separated by |
dialect |
Dialect used for parsing. |
schema |
Optional schema specification (see |
A character vector with one optimized statement per input statement.
sql_optimize("SELECT * FROM (SELECT a FROM t) AS sub WHERE sub.a > 1")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.