| sql_tokenize | R Documentation |
Splits SQL into lexical tokens using the tokenizer of the given dialect.
sql_tokenize(sql, dialect = "generic")
sql |
A single character string with one or more SQL statements
(separated by |
dialect |
Dialect used for parsing. |
A data frame with class polyglot_tokens and one row per token:
type (token type, e.g. "Select", "Identifier", "Number"),
text (raw token text), line and column (1-based position),
start and end (byte offsets, end exclusive).
sql_tokenize("SELECT a FROM t")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.