| sql_validate | R Documentation |
Checks that SQL parses in the given dialect and, optionally, applies stricter syntax rules, semantic lint warnings, and schema-aware checks.
sql_validate(sql, dialect = "generic", ...)
sql |
A single character string with one or more SQL statements
(separated by |
dialect |
Dialect used for parsing. |
... |
Additional validation options:
|
A polyglot_validation object: a list with valid (logical) and
errors (data frame with columns severity, code, message, line,
column).
sql_validate("SELECT a FROM t")
sql_validate("SELECT FROM WHERE")
v <- sql_validate("SELECT a, FROM t", strict_syntax = TRUE)
v$valid
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.